@@ -464,6 +464,15 @@ public class MyFacesGenericPortlet extends GenericPortlet
         {
             HttpServletResponseWrapper responseWrapper = new HttpServletResponseWrapper((HttpServletResponse) response);
             ExtensionsResponseWrapper exResponse = new ExtensionsResponseWrapper((HttpServletResponse) responseWrapper);
+            exResponse.getWriter().write("<head></head>");
+            exResponse.finishResponse();
+            if (log.isDebugEnabled())
+            {
+                log.debug("facesRender(RenderRequest, RenderResponse) -" + " exResponse.toString()="
+                        + exResponse.toString());
+            }
+
+            //TODO should not use HttpServletRequest(AddResource was refactered after 1.1.1...)
             AddResource.writeWithFullHeader((HttpServletRequest) request, exResponse, responseWrapper);
 
             String headerString = responseWrapper.getStringWriter().toString();
